Crate pokemon_tcg_sdk_rs

Crate pokemon_tcg_sdk_rs 

Modules

models

Structs

Client

Constants

POKEMON_TCG_URL

Traits

Query
Used to implement Query Logic for the Pokemon TCG v2 API. Url internal trait is used to implement the different subroutes for the types: Card, Rarity, Set, Type, Supertype and Subtype.