Crate pokemon_tcg_sdk_rs
pokemon_
tcg_
sdk_
rs
0.1.0
All Items
Crate Items
Modules
Structs
Constants
Traits
Crate
pokemon_
tcg_
sdk_
rs
Modules

models
Structs

Client
Constants

POKEMON_
TCG_
URL
Traits

Query
Used to implement Query Logic for the Pokemon TCG v2 API. Url internal trait is used to implement the different subroutes for the types: Card, Rarity, Set, Type, Supertype and Subtype.